@@ -8,15 +8,12 @@ function(x, ...){
   estT <- character(0)
   glpOrder <- x$glpOrder
   est <- c(est, x$constant)
-  estT <- c(estT, paste0(
-            ifelse(d==0,"mean","constant"),
-            ifelse(x$blueQ," (blue)", "")
-            ))
+  estT <- c(estT, ifelse(d==0,"mean","constant"))
   if (glpOrder==2) {
+    est <- c(est, x$dHat) #d is first
+    estT <- c(estT, "d")
     est <- c(est, x$lambdaHat)
     estT <- c(estT, "lambda")
-    est <- c(est, x$dHat)
-    estT <- c(estT, "d")
   } else {
     if(glpOrder==1) {
       est <- c(est, x$dHat)
@@ -32,13 +29,13 @@ function(x, ...){
     estT <- c(estT, paste0("theta(", paste0(1:q, ")")))      
   }
   whichModel <- paste0(x$glp, "(", p, ",", d, ",", q, ")" )
-  cat(paste0(whichModel, ", MLE Algorithm: ", x$likAlg),fill=TRUE)
+  cat(paste0(whichModel, ", MLE Algorithm: ", x$likAlg, ", optim: ",x$optAlg),
+      fill=TRUE)
   cat(paste0("snr = ", round(x$snr,3), ", sigmaSq = ", 
              x$sigmaSq), fill=TRUE)
   if (x$convergence!=0) {
     cat(paste0("Note: possible problem with convergence\n  convergence=",
                x$convergence), fill=TRUE)
-    cat(paste("Algorithm used: ", x$algorithm), fill=TRUE)
     if (!is.null(x$message)) 
       cat(paste0("message =", x$message), fill=TRUE)
   }
@@ -46,8 +43,8 @@ function(x, ...){
   LL <- x$LL
   aic <- -2*LL + 2*k
   bic <- -2*LL + k*log(x$n)
-  cat(paste0("log-likelihood =", round(LL,3), ", AIC = ", round(aic,1), 
-      ", BIC = ", round(bic,1)),  fill=TRUE)
+  cat(paste0("log-likelihood = ", round(LL,2), ", AIC = ", round(aic,2), 
+      ", BIC = ", round(bic,2)),  fill=TRUE)
   if (x$onBoundary) {
     cat("Warning: estimates converged to boundary!", fill=TRUE)
   }
